==> jbpm-flow-0.7.0-sources.jar: org/jbpm/marshalling/impl/ProcessInstanceMarshaller.java <==
/*
 * Copyright 2017 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.jbpm.marshalling.impl;

import java.io.IOException;

import org.drools.core.marshalling.impl.InputMarshaller;
import org.drools.core.marshalling.impl.MarshallerReaderContext;
import org.drools.core.marshalling.impl.MarshallerWriteContext;
import org.kie.api.runtime.process.NodeInstance;
import org.kie.api.runtime.process.NodeInstanceContainer;
import org.kie.api.runtime.process.ProcessInstance;
import org.kie.api.runtime.process.WorkflowProcessInstance;

/**
 * A ProcessInstanceMarshaller must contain all the write/read logic for nodes
 * of a specific ProcessInstance. It colaborates with OutputMarshaller and
 * InputMarshaller, that delegates in a ProcessInstanceMarshaller to stream in/out runtime
 * information.
 * 
 * @see org.drools.core.marshalling.impl.OutputMarshaller
 * @see InputMarshaller
 * @see ProcessMarshallerRegistry
 * 
 */

public interface ProcessInstanceMarshaller {

	public Object writeProcessInstance(MarshallerWriteContext context,
	                                   ProcessInstance processInstance) throws IOException;

	public Object writeNodeInstance(MarshallerWriteContext context,
	                                NodeInstance nodeInstance) throws IOException;

	public ProcessInstance readProcessInstance(MarshallerReaderContext context) throws IOException;

	public NodeInstance readNodeInstance(MarshallerReaderContext context,
	                                     NodeInstanceContainer nodeInstanceContainer,
	                                     WorkflowProcessInstance processInstance) throws IOException;
}

==> jbpm-flow-0.13.0-sources.jar: org/jbpm/marshalling/impl/ProcessInstanceMarshaller.java <==
/*
 * Copyright 2017 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.jbpm.marshalling.impl;

import java.io.IOException;

import org.drools.core.marshalling.impl.InputMarshaller;
import org.drools.core.marshalling.impl.MarshallerReaderContext;
import org.drools.core.marshalling.impl.MarshallerWriteContext;
import org.kie.api.runtime.process.NodeInstance;
import org.kie.api.runtime.process.NodeInstanceContainer;
import org.kie.api.runtime.process.ProcessInstance;
import org.kie.api.runtime.process.WorkflowProcessInstance;

/**
 * A ProcessInstanceMarshaller must contain all the write/read logic for nodes
 * of a specific ProcessInstance. It colaborates with OutputMarshaller and
 * InputMarshaller, that delegates in a ProcessInstanceMarshaller to stream in/out runtime
 * information.
 *
 * @see org.drools.core.marshalling.impl.OutputMarshaller
 * @see InputMarshaller
 * @see ProcessMarshallerRegistry
 */

public interface ProcessInstanceMarshaller {

    Object writeProcessInstance(MarshallerWriteContext context, ProcessInstance processInstance) throws IOException;

    Object writeNodeInstance(MarshallerWriteContext context, NodeInstance nodeInstance) throws IOException;

    ProcessInstance readProcessInstance(MarshallerReaderContext context) throws IOException;

    NodeInstance readNodeInstance(MarshallerReaderContext context, NodeInstanceContainer nodeInstanceContainer, WorkflowProcessInstance processInstance) throws IOException;
}
